@@ -1,5 +1,5 @@
 /*
- * $Id: fccase.tmpl.h,v 1.1 2004/12/29 09:15:17 keithp Exp $
+ * fontconfig/fc-case/fccase.tmpl.h
  *
  * Copyright © 2003 Keith Packard
  *
@@ -13,16 +13,16 @@
  * representations about the suitability of this software for any purpose.  It
  * is provided "as is" without express or implied warranty.
  *
- * KEITH PACKARD DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
+ * THE AUTHOR(S) DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO
- * EVENT SHALL KEITH PACKARD BE LIABLE FOR ANY SPECIAL, INDIRECT OR
+ * EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY SPECIAL, INDIRECT OR
  * CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
  * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
  * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  * PERFORMANCE OF THIS SOFTWARE.
  */
 
-#define FC_NUM_CASE_FOLD	218
+#define FC_NUM_CASE_FOLD	238
 #define FC_NUM_CASE_FOLD_CHARS	469
 #define FC_MAX_CASE_FOLD_CHARS	6
 #define FC_MAX_CASE_FOLD_EXPAND	4
@@ -89,6 +89,15 @@ static const FcCaseFold    fcCaseFold[FC_NUM_CASE_FOLD] = {
     { 0x000001f8, FC_CASE_FOLD_EVEN_ODD, 0x0027,      1 },
     { 0x00000220, FC_CASE_FOLD_RANGE,    0x0001,   -130 },
     { 0x00000222, FC_CASE_FOLD_EVEN_ODD, 0x0011,      1 },
+    { 0x0000023a, FC_CASE_FOLD_RANGE,    0x0001,  10795 },
+    { 0x0000023b, FC_CASE_FOLD_EVEN_ODD, 0x0001,      1 },
+    { 0x0000023d, FC_CASE_FOLD_RANGE,    0x0001,   -163 },
+    { 0x0000023e, FC_CASE_FOLD_RANGE,    0x0001,  10792 },
+    { 0x00000241, FC_CASE_FOLD_EVEN_ODD, 0x0001,      1 },
+    { 0x00000243, FC_CASE_FOLD_RANGE,    0x0001,   -195 },
+    { 0x00000244, FC_CASE_FOLD_RANGE,    0x0001,     69 },
+    { 0x00000245, FC_CASE_FOLD_RANGE,    0x0001,     71 },
+    { 0x00000246, FC_CASE_FOLD_EVEN_ODD, 0x0009,      1 },
     { 0x00000345, FC_CASE_FOLD_RANGE,    0x0001,    116 },
     { 0x00000386, FC_CASE_FOLD_RANGE,    0x0001,     38 },
     { 0x00000388, FC_CASE_FOLD_RANGE,    0x0003,     37 },
@@ -111,16 +120,17 @@ static const FcCaseFold    fcCaseFold[FC_NUM_CASE_FOLD] = {
     { 0x000003f7, FC_CASE_FOLD_EVEN_ODD, 0x0001,      1 },
     { 0x000003f9, FC_CASE_FOLD_RANGE,    0x0001,     -7 },
     { 0x000003fa, FC_CASE_FOLD_EVEN_ODD, 0x0001,      1 },
+    { 0x000003fd, FC_CASE_FOLD_RANGE,    0x0003,   -130 },
     { 0x00000400, FC_CASE_FOLD_RANGE,    0x0010,     80 },
     { 0x00000410, FC_CASE_FOLD_RANGE,    0x0020,     32 },
     { 0x00000460, FC_CASE_FOLD_EVEN_ODD, 0x0021,      1 },
     { 0x0000048a, FC_CASE_FOLD_EVEN_ODD, 0x0035,      1 },
+    { 0x000004c0, FC_CASE_FOLD_RANGE,    0x0001,     15 },
     { 0x000004c1, FC_CASE_FOLD_EVEN_ODD, 0x000d,      1 },
-    { 0x000004d0, FC_CASE_FOLD_EVEN_ODD, 0x0025,      1 },
-    { 0x000004f8, FC_CASE_FOLD_EVEN_ODD, 0x0001,      1 },
-    { 0x00000500, FC_CASE_FOLD_EVEN_ODD, 0x000f,      1 },
+    { 0x000004d0, FC_CASE_FOLD_EVEN_ODD, 0x0043,      1 },
     { 0x00000531, FC_CASE_FOLD_RANGE,    0x0026,     48 },
     { 0x00000587, FC_CASE_FOLD_FULL,     0x0004,     23 },
+    { 0x000010a0, FC_CASE_FOLD_RANGE,    0x0026,   7264 },
     { 0x00001e00, FC_CASE_FOLD_EVEN_ODD, 0x0095,      1 },
     { 0x00001e96, FC_CASE_FOLD_FULL,     0x0003,     27 },
     { 0x00001e97, FC_CASE_FOLD_FULL,     0x0003,     30 },
@@ -232,8 +242,18 @@ static const FcCaseFold    fcCaseFold[FC_NUM_CASE_FOLD] = {
     { 0x00002126, FC_CASE_FOLD_RANGE,    0x0001,  -7517 },
     { 0x0000212a, FC_CASE_FOLD_RANGE,    0x0001,  -8383 },
     { 0x0000212b, FC_CASE_FOLD_RANGE,    0x0001,  -8262 },
+    { 0x00002132, FC_CASE_FOLD_RANGE,    0x0001,     28 },
     { 0x00002160, FC_CASE_FOLD_RANGE,    0x0010,     16 },
+    { 0x00002183, FC_CASE_FOLD_EVEN_ODD, 0x0001,      1 },
     { 0x000024b6, FC_CASE_FOLD_RANGE,    0x001a,     26 },
+    { 0x00002c00, FC_CASE_FOLD_RANGE,    0x002f,     48 },
+    { 0x00002c60, FC_CASE_FOLD_EVEN_ODD, 0x0001,      1 },
+    { 0x00002c62, FC_CASE_FOLD_RANGE,    0x0001, -10743 },
+    { 0x00002c63, FC_CASE_FOLD_RANGE,    0x0001,  -3814 },
+    { 0x00002c64, FC_CASE_FOLD_RANGE,    0x0001, -10727 },
+    { 0x00002c67, FC_CASE_FOLD_EVEN_ODD, 0x0005,      1 },
+    { 0x00002c75, FC_CASE_FOLD_EVEN_ODD, 0x0001,      1 },
+    { 0x00002c80, FC_CASE_FOLD_EVEN_ODD, 0x0063,      1 },
     { 0x0000fb00, FC_CASE_FOLD_FULL,     0x0002,    433 },
     { 0x0000fb01, FC_CASE_FOLD_FULL,     0x0002,    435 },
     { 0x0000fb02, FC_CASE_FOLD_FULL,     0x0002,    437 },
